%global __requires_exclude ^%{python3}$

%ifarch x86_64 aarch64 loongarch64
%global have_uefi 1
%global have_gpio 1
%endif

%ifarch x86_64 aarch64 ppc64le
%global have_flashrom 1
%endif

%ifarch loongarch64
%global have_flashrom 0
%endif

%ifarch x86_64
%global have_msr 1
%global have_dell 1
%global have_thunderbolt 1
%endif

Summary:   Firmware update daemon
Name:      fwupd
Version:   1.8.10
Release:   11%{?dist}
License:   LGPLv2+
URL:       https://github.com/fwupd/fwupd
Source0:   http://people.freedesktop.org/~hughsient/releases/%{name}-%{version}.tar.xz

# fix "no data for compatible" in fwupd tests: `fwupdtool get-devices --verbose`
# in !x86 arches
# https://github.com/fwupd/fwupd/pull/5443/commits/629c83e48b34294c1fba0b39c70024489d1305c4
Patch0001: 0001-Do-not-make-any-of-the-HWIDs-setup-failures-fatal.patch

Patch3000: 0001-fwupd-1.8.10-add-support-for-loongarch64.patch

BuildRequires: libgcab1-devel libgusb-devel >= 0.3.5
BuildRequires: libcurl-devel >= 7.62.0 libjcat-devel >= 0.1.0
BuildRequires: polkit-devel >= 0.103 protobuf-c-devel
BuildRequires: python3-packaging sqlite-devel libcbor-devel
BuildRequires: systemd >= 231 systemd-devel libarchive-devel libgudev1-devel
BuildRequires: gobject-introspection-devel gcab
BuildRequires: gnutls-devel gnutls-utils meson vala
BuildRequires: json-glib-devel >= 1.1.1 gettext libxmlb-devel >= 0.1.3
BuildRequires: bash-completion git-core
BuildRequires: ModemManager-glib-devel >= 1.10.0 glib2-devel
BuildRequires: libqmi-devel >= 1.22.0 libmbim-devel

%ifarch %{valgrind_arches}
BuildRequires: valgrind
BuildRequires: valgrind-devel
%endif

%if 0%{?have_flashrom}
BuildRequires: flashrom-devel >= 1.2
%endif

%if 0%{?have_uefi}
BuildRequires: efivar-devel >= 33
BuildRequires: python3 python3-cairo python3-gobject
BuildRequires: pango-devel
BuildRequires: cairo-devel cairo-gobject-devel
BuildRequires: freetype
BuildRequires: fontconfig
BuildRequires: google-noto-sans-cjk-ttc-fonts
BuildRequires: tpm2-tss-devel >= 2.2.3
%endif

%if 0%{?have_dell}
BuildRequires: efivar-devel >= 33
BuildRequires: libsmbios-devel >= 2.3.0
%endif

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

Requires: glib2
Requires: libxmlb >= 0.1.3
Requires: libgusb >= 0.3.5
Requires: shared-mime-info

Provides: dbxtool

Recommends: udisks2
Recommends: bluez
Recommends: jq
Recommends: %{name}-plugin-modem-manager

%if 0%{?have_flashrom}
Recommends: %{name}-plugin-flashrom
%endif
%if 0%{?have_uefi}
Recommends: %{name}-efi
Recommends: %{name}-plugin-uefi-capsule-data
%endif

%description
A system daemon to allow session software to update firmware

%package devel
Summary: Development package for %{name}
Requires: %{name} = %{version}-%{release}

%description devel
This package provides files for development.

%package tests
Summary: Data files for installed tests
Requires: %{name} = %{version}-%{release}

%description tests
This package provides data files for installed tests.

%package plugin-modem-manager
Summary: fwupd plugin using ModemManger
Requires: %{name} = %{version}-%{release}

%description plugin-modem-manager
This provides the optional package which is only required on hardware that
might have mobile broadband hardware. It is probably not required on servers.

%if 0%{?have_flashrom}
%package plugin-flashrom
Summary: fwupd plugin using flashrom
Requires: %{name} = %{version}-%{release}

%description plugin-flashrom
This package provides interfaces which ires only required on hardware that
can be flashed using flashrom.
%endif

%if 0%{?have_uefi}
%package plugin-uefi-capsule-data
Summary: Localized data for the UEFI UX capsule
Requires: %{name} = %{version}-%{release}

%description plugin-uefi-capsule-data
This package provides the pregenerated BMP artwork for the UX capsule.
%endif

%prep
%autosetup -p1

%build

%meson \
    -Ddocs=disabled \
    -Dtests=true \
    -Dplugin_dummy=true \
%if 0%{?have_flashrom}
    -Dplugin_flashrom=enabled \
%else
    -Dplugin_flashrom=disabled \
%endif
%if 0%{?have_msr}
    -Dplugin_msr=enabled \
%else
    -Dplugin_msr=disabled \
%endif
%if 0%{?have_gpio}
    -Dplugin_gpio=enabled \
%else
    -Dplugin_gpio=disabled \
%endif
%if 0%{?have_uefi}
    -Dplugin_uefi_capsule=enabled \
    -Dplugin_uefi_pk=enabled \
    -Dplugin_tpm=enabled \
    -Defi_binary=false \
%else
    -Dplugin_uefi_capsule=disabled \
    -Dplugin_uefi_pk=disabled \
    -Dplugin_tpm=disabled \
%endif
%if 0%{?have_dell}
    -Dplugin_dell=enabled \
%else
    -Dplugin_dell=disabled \
%endif
    -Dplugin_modem_manager=enabled \
    -Dman=true \
    -Dbluez=enabled \
    -Dplugin_powerd=disabled \
    -Dsupported_build=enabled

%meson_build



%install
%meson_install

mkdir -p --mode=0700 %{buildroot}%{_localstatedir}/lib/fwupd/gnupg
mkdir -p %{buildroot}%{_localstatedir}/cache/fwupd

%find_lang %{name}



%check
%ifnarch loongarch64
%meson_test
%endif



%post
%systemd_post fwupd.service

for fn in /etc/fwupd/remotes.d/*.conf; do
    if grep -q "Keyring=gpg" "$fn"; then
        sed -i 's/Keyring=gpg/#Keyring=pkcs/g' "$fn";
    fi
done

%preun
%systemd_preun fwupd.service

%postun
%systemd_postun_with_restart fwupd.service

%files -f %{name}.lang
%license COPYING
%doc README.md AUTHORS
%{_bindir}/fwupdmgr
%{_bindir}/fwupdtool
%{_bindir}/fwupdagent
%{_bindir}/dbxtool
%{_bindir}/dfu-tool
%config(noreplace)%{_sysconfdir}/fwupd/redfish.conf
%config(noreplace)%{_sysconfdir}/fwupd/daemon.conf
%config(noreplace)%{_sysconfdir}/fwupd/bios-settings.d/README.md
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/lvfs.conf
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/lvfs-testing.conf
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/vendor.conf
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/vendor-directory.conf
%config(noreplace)%{_sysconfdir}/pki/fwupd
%{_sysconfdir}/pki/fwupd-metadata
%dir %{_libexecdir}/fwupd
%{_libexecdir}/fwupd/fwupd
%{_libexecdir}/fwupd/fwupdoffline
%dir %{_sysconfdir}/fwupd
%dir %{_sysconfdir}/fwupd/bios-settings.d
%dir %{_sysconfdir}/fwupd/remotes.d
%{_datadir}/dbus-1/system.d/org.freedesktop.fwupd.conf
%{_datadir}/bash-completion/completions/fwupdmgr
%{_datadir}/bash-completion/completions/fwupdtool
%{_datadir}/bash-completion/completions/fwupdagent
%{_datadir}/fish/vendor_completions.d/fwupdmgr.fish
%{_datadir}/fwupd/metainfo/org.freedesktop.fwupd*.metainfo.xml
%{_datadir}/fwupd/remotes.d/vendor/firmware/README.md
%{_datadir}/dbus-1/interfaces/org.freedesktop.fwupd.xml
%{_datadir}/polkit-1/actions/org.freedesktop.fwupd.policy
%{_datadir}/polkit-1/rules.d/org.freedesktop.fwupd.rules
%{_datadir}/dbus-1/system-services/org.freedesktop.fwupd.service
%{_datadir}/fwupd/quirks.d/builtin.quirk.gz
%{_datadir}/metainfo/org.freedesktop.fwupd.metainfo.xml
%{_datadir}/icons/hicolor/scalable/apps/org.freedesktop.fwupd.svg
%{_datadir}/fwupd/firmware_packager.py
%{_datadir}/fwupd/simple_client.py
%{_datadir}/fwupd/add_capsule_header.py
%{_datadir}/fwupd/install_dell_bios_exe.py
%{_unitdir}/fwupd-offline-update.service
%{_unitdir}/fwupd.service
%{_unitdir}/fwupd-refresh.service
%{_unitdir}/fwupd-refresh.timer
%{_presetdir}/fwupd-refresh.preset
%{_unitdir}/system-update.target.wants/
%dir %{_localstatedir}/lib/fwupd
%dir %{_localstatedir}/cache/fwupd
%dir %{_datadir}/fwupd/quirks.d
%{_libdir}/libfwupd.so.2*
%{_libdir}/girepository-1.0/Fwupd-2.0.typelib
/usr/lib/udev/rules.d/*.rules
/usr/lib/systemd/system-shutdown/fwupd.shutdown
%dir %{_libdir}/fwupd-%{version}
%{_libdir}/fwupd-%{version}/libfwupd*.so
%ghost %{_localstatedir}/lib/fwupd/gnupg
%{_mandir}/man1/fwupdtool.1*
%{_mandir}/man1/fwupdagent.1*
%{_mandir}/man1/dfu-tool.1*
%{_mandir}/man1/fwupdmgr.1*

%if 0%{?have_uefi}
%{_bindir}/fwupdate
%{_bindir}/dbxtool
%config(noreplace)%{_sysconfdir}/fwupd/uefi_capsule.conf
%{_sysconfdir}/grub.d/35_fwupd
%{_mandir}/man1/dbxtool.*
%{_mandir}/man1/fwupdate.1*
%endif

%if 0%{?have_thunderbolt}
%config(noreplace)%{_sysconfdir}/fwupd/thunderbolt.conf
%endif

%ifarch x86_64
%{_libexecdir}/fwupd/fwupd-detect-cet
%endif
%if 0%{?have_dell}
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/dell-esrt.conf
%{_datadir}/fwupd/remotes.d/dell-esrt/metadata.xml
%endif
%if 0%{?have_msr}
/usr/lib/modules-load.d/fwupd-msr.conf
%config(noreplace)%{_sysconfdir}/fwupd/msr.conf
%endif

%files plugin-modem-manager
%{_libdir}/fwupd-%{version}/libfu_plugin_modem_manager.so

%if 0%{?have_flashrom}
%files plugin-flashrom
%{_libdir}/fwupd-%{version}/libfu_plugin_flashrom.so
%endif

%if 0%{?have_uefi}
%files plugin-uefi-capsule-data
%{_datadir}/fwupd/uefi-capsule-ux.tar.xz
%endif

%files devel
%{_includedir}/fwupd-1
%{_libdir}/libfwupd*.so
%{_libdir}/pkgconfig/fwupd.pc
%{_datadir}/gir-1.0/Fwupd-2.0.gir
%{_datadir}/vala/vapi

%files tests
%{_datadir}/fwupd/host-emulate.d/*.json.gz
%dir %{_datadir}/installed-tests/fwupd
%{_datadir}/installed-tests/fwupd/tests/*
%{_datadir}/installed-tests/fwupd/fwupd-tests.xml
%{_datadir}/installed-tests/fwupd/*.test
%{_datadir}/installed-tests/fwupd/*.cab
%{_datadir}/installed-tests/fwupd/*.sh
%{_datadir}/installed-tests/fwupd/chassis_type
%{_datadir}/installed-tests/fwupd/firmware.zip
%{_datadir}/installed-tests/fwupd/sys_vendor
%if 0%{?have_uefi}
%{_datadir}/installed-tests/fwupd/efi
%endif
%{_datadir}/fwupd/device-tests/*.json
%{_libexecdir}/installed-tests/fwupd/*
%dir %{_sysconfdir}/fwupd/remotes.d
%config(noreplace)%{_sysconfdir}/fwupd/remotes.d/fwupd-tests.conf

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.10-11
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.10-10
- Rebuilt for loongarch release

* Mon Aug 12 2024 Yi Lin <nilusyi@tencent.com> - 1.8.10-9
- [Type] other
- [DESC] fix "no data for compatible" in fwupd tests: `fwupdtool get-devices --verbose`

* Tue Jul 16 2024 Pengda Dou <doupengda@loongson> - 1.8.10-8
- [Type] other
- [DESC] fix build error for loongarch64

* Mon Jul 15 2024 Pengda Dou <doupengda@loongson> - 1.8.10-7
- [Type] other
- [DESC] fix build error for loongarch64

* Thu May 30 2024 Pengda Dou <doupengda@loongson.cn> - 1.8.10-6
- [Type] other
- [DESC] add support for loongarch64

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 1.8.10-5
- Rebuild for curl-8.4.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.10-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 18 2023 cunshunxia <cunshunxia@tencent.com> - 1.8.10-3
- Rebuilt for tpm2-tss 4.0.1

* Mon Jul 17 2023 cunshunxia <cunshunxia@tencent.com> - 1.8.10-2
- rebuild for ModemManager 1.20.2

* Wed Jul 12 2023 cunshunxia <cunshunxia@tencent.com> - 1.8.10-1
- upgrade to 1.8.10

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.7-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.8.7-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Nov 21 2022 cunshunxia <cunshunxia@tencent.com> - 1.8.7-1
- initial build
